From: Petri Savolainen <petri.savolai...@linaro.org>

Require that implementation initializes the pointer value
to NULL. Application can use the pointer more robustly when
it can tell if the pointer has been set previously or not.

Signed-off-by: Petri Savolainen <petri.savolai...@linaro.org>
---
/** Email created from pull request 388 (psavol:next-user-ptr-init)
 ** https://github.com/Linaro/odp/pull/388
 ** Patch: https://github.com/Linaro/odp/pull/388.patch
 ** Base sha: 6303c7d0e98fafe0f14c8c4dd9989b3b7633ebf4
 ** Merge commit sha: 76bd874ba5677533132a4c0a39c8e5cf9049a9af
 **/
 include/odp/api/spec/packet.h | 11 +++++++----
 1 file changed, 7 insertions(+), 4 deletions(-)

diff --git a/include/odp/api/spec/packet.h b/include/odp/api/spec/packet.h
index 3655f5899..8aca552f6 100644
--- a/include/odp/api/spec/packet.h
+++ b/include/odp/api/spec/packet.h
@@ -1341,7 +1341,10 @@ int odp_packet_input_index(odp_packet_t pkt);
 /**
  * User context pointer
  *
- * Return previously stored user context pointer.
+ * Return previously stored user context pointer. If not otherwise documented,
+ * the pointer value is maintained over packet manipulating operations.
+ * Implementation initializes the pointer value to NULL during new packet
+ * creation (e.g. alloc and packet input) and reset.
  *
  * @param pkt  Packet handle
  *
@@ -1357,10 +1360,10 @@ void *odp_packet_user_ptr(odp_packet_t pkt);
  * value of type intptr_t. ODP may use the pointer for data prefetching, but
  * must ignore any invalid addresses.
  *
  * @param pkt  Packet handle
  * @param ctx  User context pointer
  */
-void odp_packet_user_ptr_set(odp_packet_t pkt, const void *ctx);
+void odp_packet_user_ptr_set(odp_packet_t pkt, const void *user_ptr);
 
 /**
  * User area address
@@ -1357,10 +1360,10 @@ void *odp_packet_user_ptr(odp_packet_t pkt);
  * must ignore any invalid addresses.
  *
- * @param pkt  Packet handle
- * @param ctx  User context pointer
+ * @param pkt       Packet handle
+ * @param user_ptr  User context pointer
  */

Reply via email to